# Copyright 2025 Amazon.com, Inc. or its affiliates.
# SPDX-License-Identifier: Apache-2.0

"""
Document Accessibility Package.

This package provides tools for converting PDF documents to accessible HTML,
auditing HTML for accessibility issues, and remediating those issues.

Main Components:
- PDF to HTML conversion
- HTML accessibility auditing
- HTML accessibility remediation
"""

__version__ = "0.6.1"  # Main project uses this version!
