# Copyright 2025 Amazon.com, Inc. or its affiliates.
# SPDX-License-Identifier: Apache-2.0

"""
PDF to HTML conversion module.

This module provides functionality for converting PDF documents to HTML
using AWS Bedrock Data Automation.
"""

