# Copyright 2025 Amazon.com, Inc. or its affiliates.
# SPDX-License-Identifier: Apache-2.0

"""
HTML Accessibility Remediation Prompt Generators.

This module provides classes for generating prompts used by AI models
to remediate specific types of accessibility issues.
"""

