# Copyright 2025 Amazon.com, Inc. or its affiliates.
# SPDX-License-Identifier: Apache-2.0

"""
Batch processing module for document_accessibility.

This module provides functionality for integrating the document_accessibility
solution into a large-scale, decoupled processing mechanism using AWS services.
"""

__all__ = ["pdf2html", "audit", "remediate"]
