# Copyright 2025 Amazon.com, Inc. or its affiliates.
# SPDX-License-Identifier: Apache-2.0

"""
HTML Accessibility Remediator Helpers.

This module provides helper functions and classes used by the remediation process.
"""

