# Copyright 2025 Amazon.com, Inc. or its affiliates.
# SPDX-License-Identifier: Apache-2.0

"""
PDF to HTML services subpackage.

This subpackage provides services integration for the PDF to HTML conversion,
including AWS Bedrock Data Automation client.
"""

