# Copyright 2025 Amazon.com, Inc. or its affiliates.
# SPDX-License-Identifier: Apache-2.0

"""
HTML Accessibility Analyzers.

This module provides analyzer classes for specific types of accessibility checks.
"""

from content_accessibility_utility_on_aws.audit.analyzers.base_analyzer import BaseAnalyzer

__all__ = ["BaseAnalyzer"]
